/*
 *  $Id: serverhunter.h,v 1.6 2002/08/22 09:37:25 dreibh Exp $
 *
 * RSerPool implementation.
 *
 * Realized in co-operation between Siemens AG
 * and University of Essen, Institute of Computer Networking Technology.
 *
 * Acknowledgement
 * This work was partially funded by the Bundesministerium fr Bildung und
 * Forschung (BMBF) of the Federal Republic of Germany (Frderkennzeichen 01AK045).
 * The authors alone are responsible for the contents.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * There are two mailinglists available at http://www.sctp.de/rserpool.html
 * which should be used for any discussion related to this implementation.
 *
 * Contact: rsplib-discussion@sctp.de
 *          dreibh@exp-math.uni-essen.de
 *
 * Purpose: Name Server Hunter
 *
 */


#ifndef SERVERHUNTER_H
#define SERVERHUNTER_H


#include "tdtypes.h"
#include "serverinfolist.h"
#include "asapmessage.h"


#ifdef __cplusplus
extern "C" {
#endif


struct ServerHunter
{
   struct ServerInfoList* ServerList;
   struct ASAPMessage*    Message;

   int                    IPv4ServerHuntSocket;
#ifdef HAVE_IPV6
   int                    IPv6ServerHuntSocket;
#endif

   size_t                 ValidServers;
   char                   Buffer[1024];
};



/**
  * Constructor.
  *
  * @return ServerHunter or NULL in case of error.
  */
struct ServerHunter* serverHunterNew();

/**
  * Destructor.
  *
  * @param serverHunter ServerHunter.
  */
void serverHunterDelete(struct ServerHunter* serverHunter);

/**
  * Do server hunt.
  *
  * @param serverHunter ServerHunter.
  * @param sd Reference to store socket descriptor of first name server connection to.
  * @param serverHuntTimeout Timeout for the first trial. It will double each trail until maxServerHuntTimeout is reached.
  * @param maxServerHuntTimeout Maximum timeout for a trial.
  * @param maxServerHuntTrials Maximum number of server hunt trials.
  * @param configFile Name of ASAP configuration file.
  * @return Number of valid servers seen.
  */
unsigned int serverHunterRun(struct ServerHunter* serverHunter,
                             int*                 sd,
                             const card64         serverHuntTimeout,
                             const card64         maxServerHuntTimeout,
                             const unsigned int   maxServerHuntTrials,
                             const char*          configFile);



#ifdef __cplusplus
}
#endif


#endif
