/*
 *  $Id: serverinfo.c,v 1.3 2002/08/22 09:37:26 dreibh Exp $
 *
 * RSerPool implementation.
 *
 * Realized in co-operation between Siemens AG
 * and University of Essen, Institute of Computer Networking Technology.
 *
 * Acknowledgement
 * This work was partially funded by the Bundesministerium fr Bildung und
 * Forschung (BMBF) of the Federal Republic of Germany (Frderkennzeichen 01AK045).
 * The authors alone are responsible for the contents.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * There are two mailinglists available at http://www.sctp.de/rserpool.html
 * which should be used for any discussion related to this implementation.
 *
 * Contact: rsplib-discussion@sctp.de
 *          dreibh@exp-math.uni-essen.de
 *
 * Purpose: Name Server Information
 *
 */


#include "tdtypes.h"
#include "serverinfo.h"
#include "utilities.h"



/* ###### Constructor #################################################### */
struct ServerInfo* serverInfoNew(const uint32_t           serverID,
                                 struct TransportAddress* transportAddress,
                                 const unsigned int       flags)
{
   struct ServerInfo* serverInfo = (struct ServerInfo*)malloc(sizeof(struct ServerInfo));
   if(serverInfo != NULL) {
      serverInfo->ServerID  = serverID;
      serverInfo->Flags     = flags;
      serverInfo->Address   = transportAddress;
      serverInfo->TimeStamp = getMicroTime();
   }
   return(serverInfo);
}


/* ###### Destructor ##################################################### */
void serverInfoDelete(struct ServerInfo* serverInfo)
{
   if(serverInfo != NULL) {
      if(serverInfo->Address) {
         transportAddressDelete(serverInfo->Address);
         serverInfo->Address = NULL;
      }
      free(serverInfo);
   }
}


/* ###### Duplicate ServerInfo ########################################### */
struct ServerInfo* serverInfoDuplicate(struct ServerInfo* serverInfo)
{
   struct ServerInfo*       copy = NULL;
   struct TransportAddress* transportAddress;

   if(serverInfo != NULL) {
      transportAddress = transportAddressDuplicate(serverInfo->Address);
      if(transportAddress != NULL) {
         copy = serverInfoNew(serverInfo->ServerID,
                              transportAddress,
                              serverInfo->Flags);
         if(copy == NULL) {
            transportAddressDelete(transportAddress);
         }
      }
   }
   return(copy);
}


/* ###### Print ServerInfo ############################################### */
void serverInfoPrint(struct ServerInfo* serverInfo, FILE* fd)
{
   if(serverInfo != NULL) {
      fprintf(fd,"ServerID $%08x\n",serverInfo->ServerID);
      fputs("   Flags    =",fd);
      if(serverInfo->Flags & SF_PERMANENT) {
         fputs(" Permanent",fd);
      }
      if(serverInfo->Flags & SF_STATIC) {
         fputs(" Static",fd);
      }
      else {
         fputs(" Dynamic",fd);
      }
      if(serverInfo->Flags & SF_MULTICAST) {
         fputs(" Multicast",fd);
      }
      else {
         fputs(" Unicast",fd);
      }
      if(serverInfo->Flags & SF_UNKNOWN) {
         fputs(" Unknown",fd);
      }
      if(serverInfo->Flags & SF_FAILED) {
         fputs(" Failed",fd);
      }
      fputs("\n",fd);
      fputs("   Address  = ",fd);
      transportAddressPrint(serverInfo->Address,fd);
      fputs("\n",fd);
   }
   else {
      fputs("(null)\n",fd);
   }
}


/* ###### ServerInfo comparision function ################################ */
gint serverInfoCompareFunc(gconstpointer a, gconstpointer b)
{
   const struct ServerInfo* s1 = (const struct ServerInfo*)a;
   const struct ServerInfo* s2 = (const struct ServerInfo*)b;

   if(s1->ServerID < s2->ServerID) {
      return(-1);
   }
   else if(s1->ServerID > s2->ServerID) {
      return(1);
   }

   return(transportAddressCompareFunc(s1->Address,s2->Address));
}
