/*
 *  $Id: serverinfolist.h,v 1.6 2002/08/22 09:37:26 dreibh Exp $
 *
 * RSerPool implementation.
 *
 * Realized in co-operation between Siemens AG
 * and University of Essen, Institute of Computer Networking Technology.
 *
 * Acknowledgement
 * This work was partially funded by the Bundesministerium fr Bildung und
 * Forschung (BMBF) of the Federal Republic of Germany (Frderkennzeichen 01AK045).
 * The authors alone are responsible for the contents.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * There are two mailinglists available at http://www.sctp.de/rserpool.html
 * which should be used for any discussion related to this implementation.
 *
 * Contact: rsplib-discussion@sctp.de
 *          dreibh@exp-math.uni-essen.de
 *
 * Purpose: Name Server Information List
 *
 */


#ifndef SERVERINFOLIST_H
#define SERVERINFOLIST_H


#include "tdtypes.h"
#include "serverinfo.h"


#include <glib.h>


#ifdef __cplusplus
extern "C" {
#endif



struct ServerInfoList
{
   size_t UnicastServers;
   GList* UnicastServerList;

   size_t MulticastServers;
   GList* MulticastServerList;
};



/**
  * Constructor.
  *
  * @return ServerInfoList or NULL in case of error.
  */
struct ServerInfoList* serverInfoListNew();

/**
  * Destructor.
  *
  * @param serverInfoList ServerInfoList.
  */
void serverInfoListDelete(struct ServerInfoList* serverInfoList);

/**
  * Print ServerInfoList.
  *
  * @param serverInfoList ServerInfoList.
  * @param fd File to print ServerInfoList to (e.g. stdout, stderr, ...).
  */
void serverInfoListPrint(struct ServerInfoList* serverInfoList, FILE* fd);

/**
  * Clear ServerInfoList.
  *
  * @param serverInfoList ServerInfoList.
  */
void serverInfoListClear(struct ServerInfoList* serverInfoList);

/**
  * Purge ServerInfoList with given timeout.
  *
  * @param serverInfoList ServerInfoList.
  * @param timeout Timeout in microseconds.
  */
void serverInfoListPurge(struct ServerInfoList* serverInfoList, const card64 timeout);

/**
  * Add ServerInfo to ServerInfoList.
  *
  * @param serverInfoList ServerInfoList.
  * @param serverInfo ServerInfo.
  * @return true for success; false otherwise.
  */
bool serverInfoListAddServerInfo(struct ServerInfoList* serverInfoList,
                                 struct ServerInfo*     serverInfo);

/**
  * Remove ServerInfo from ServerInfoList.
  *
  * @param serverInfoList ServerInfoList.
  * @param serverInfo ServerInfo.
  */
void serverInfoListRemoveServerInfo(struct ServerInfoList* serverInfoList,
                                    struct ServerInfo*     serverInfo);

/**
  * Get static name server entries from configuration file.
  *
  * @param serverInfoList ServerInfoList.
  * @param fileName File name.
  */
bool serverInfoListGetStaticEntries(struct ServerInfoList* serverInfoList, const char* fileName);



#ifdef __cplusplus
}
#endif


#endif
